@@ -1,65 +1,69 @@
 use crate::{
-    ReadNpyError, ReadNpyExt, ReadableElement, WritableElement, WriteNpyError, WriteNpyExt
+    ReadNpyError, ReadNpyExt, ReadableElement, WritableElement, WriteNpyError, WriteNpyExt,
 };
-use ndarray::{Data, DataOwned};
 use ndarray::prelude::*;
+use ndarray::{Data, DataOwned};
 use std::error::Error;
-use std::io::{self, Read, Seek, Write};
-use zip::{CompressionMethod, ZipArchive, ZipWriter};
+use std::fmt;
+use std::io::{Read, Seek, Write};
 use zip::result::ZipError;
 use zip::write::FileOptions;
+use zip::{CompressionMethod, ZipArchive, ZipWriter};
 
-quick_error! {
-    /// An error writing a `.npz` file.
-    #[derive(Debug)]
-    pub enum WriteNpzError {
-        /// An error caused by I/O.
-        Io(err: io::Error) {
-            description("I/O error")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
+/// An error writing a `.npz` file.
+#[derive(Debug)]
+pub enum WriteNpzError {
+    /// An error caused by the zip file.
+    Zip(ZipError),
+    /// An error caused by writing an inner `.npy` file.
+    Npy(WriteNpyError),
+}
+
+impl Error for WriteNpzError {
+    fn source(&self) -> Option<&(dyn Error + 'static)> {
+        match self {
+            WriteNpzError::Zip(err) => Some(err),
+            WriteNpzError::Npy(err) => Some(err),
         }
-        /// An error caused by the zip file.
-        Zip(err: ZipError) {
-            description("zip file error")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
-        }
-        /// An error caused by writing an inner `.npy` file.
-        Npy(err: WriteNpyError) {
-            description("error writing npy file to npz archive")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
+    }
+}
+
+impl fmt::Display for WriteNpzError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            WriteNpzError::Zip(err) => write!(f, "zip file error: {}", err),
+            WriteNpzError::Npy(err) => write!(f, "error writing npy file to npz archive: {}", err),
         }
     }
 }
 
+impl From<ZipError> for WriteNpzError {
+    fn from(err: ZipError) -> WriteNpzError {
+        WriteNpzError::Zip(err)
+    }
+}
+
+impl From<WriteNpyError> for WriteNpzError {
+    fn from(err: WriteNpyError) -> WriteNpzError {
+        WriteNpzError::Npy(err)
+    }
+}
+
 /// Writer for `.npz` files.
 ///
 /// # Example
 ///
-/// ```
-/// #[macro_use]
-/// extern crate ndarray;
-/// extern crate ndarray_npy;
-///
-/// use ndarray::prelude::*;
+/// ```no_run
+/// use ndarray::{array, Array1, Array2};
 /// use ndarray_npy::NpzWriter;
 /// use std::fs::File;
-/// # use ndarray_npy::WriteNpzError;
 ///
-/// # fn write_example() -> Result<(), WriteNpzError> {
 /// let mut npz = NpzWriter::new(File::create("arrays.npz")?);
 /// let a: Array2<i32> = array![[1, 2, 3], [4, 5, 6]];
 /// let b: Array1<i32> = array![7, 8, 9];
 /// npz.add_array("a", &a)?;
 /// npz.add_array("b", &b)?;
-/// # Ok(())
-/// # }
-/// # fn main () {}
+/// # Ok::<_, Box<dyn std::error::Error>>(())
 /// ```
 pub struct NpzWriter<W: Write + Seek> {
     zip: ZipWriter<W>,
@@ -106,55 +110,58 @@ impl<W: Write + Seek> NpzWriter<W> {
     }
 }
 
-quick_error! {
-    /// An error reading a `.npz` file.
-    #[derive(Debug)]
-    pub enum ReadNpzError {
-        /// An error caused by I/O.
-        Io(err: io::Error) {
-            description("I/O error")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
+/// An error reading a `.npz` file.
+#[derive(Debug)]
+pub enum ReadNpzError {
+    /// An error caused by the zip archive.
+    Zip(ZipError),
+    /// An error caused by reading an inner `.npy` file.
+    Npy(ReadNpyError),
+}
+
+impl Error for ReadNpzError {
+    fn source(&self) -> Option<&(dyn Error + 'static)> {
+        match self {
+            ReadNpzError::Zip(err) => Some(err),
+            ReadNpzError::Npy(err) => Some(err),
         }
-        /// An error caused by the zip archive.
-        Zip(err: ZipError) {
-            description("zip file error")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
-        }
-        /// An error caused by reading an inner `.npy` file.
-        Npy(err: ReadNpyError) {
-            description("error reading npy file in npz archive")
-            display(x) -> ("{}: {}", x.description(), err)
-            cause(err)
-            from()
+    }
+}
+
+impl fmt::Display for ReadNpzError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            ReadNpzError::Zip(err) => write!(f, "zip file error: {}", err),
+            ReadNpzError::Npy(err) => write!(f, "error reading npy file in npz archive: {}", err),
         }
     }
 }
 
+impl From<ZipError> for ReadNpzError {
+    fn from(err: ZipError) -> ReadNpzError {
+        ReadNpzError::Zip(err)
+    }
+}
+
+impl From<ReadNpyError> for ReadNpzError {
+    fn from(err: ReadNpyError) -> ReadNpzError {
+        ReadNpzError::Npy(err)
+    }
+}
+
 /// Reader for `.npz` files.
 ///
 /// # Example
 ///
-/// ```
-/// #[macro_use]
-/// extern crate ndarray;
-/// extern crate ndarray_npy;
-///
-/// use ndarray::prelude::*;
+/// ```no_run
+/// use ndarray::{Array1, Array2};
 /// use ndarray_npy::NpzReader;
 /// use std::fs::File;
-/// # use ndarray_npy::ReadNpzError;
 ///
-/// # fn read_example() -> Result<(), ReadNpzError> {
 /// let mut npz = NpzReader::new(File::open("arrays.npz")?)?;
 /// let a: Array2<i32> = npz.by_name("a")?;
 /// let b: Array1<i32> = npz.by_name("b")?;
-/// # Ok(())
-/// # }
-/// # fn main() {}
+/// # Ok::<_, Box<dyn std::error::Error>>(())
 /// ```
 pub struct NpzReader<R: Read + Seek> {
     zip: ZipArchive<R>,
@@ -168,6 +175,11 @@ impl<R: Read + Seek> NpzReader<R> {
         })
     }
 
+    /// Returns `true` iff the `.npz` file doesn't contain any arrays.
+    pub fn is_empty(&self) -> bool {
+        self.zip.len() == 0
+    }
+
     /// Returns the number of arrays in the `.npz` file.
     pub fn len(&self) -> usize {
         self.zip.len()
